@@ -3,6 +3,7 @@ import numpy as np
 
 
 __all__ = [
+    'anderson_801_1982',
     'kong_61_2007b',
     'kong_121_2007',
     'kong_241_2007',
@@ -20,6 +21,42 @@ _LIBPATH = os.path.abspath(os.path.dirname(__file__))
 _CACHE = {}
 
 
+def anderson_801_1982():
+    """801 point Hankel filter, J0 and J1
+
+
+    > Anderson, W. L., 1982;
+    > Fast Hankel transforms using related and lagged convolutions;
+    > ACM Trans. on Math. Softw. (TOMS), 8, 344-368;
+    > DOI: 10.1145/356012.356014
+
+
+    The original filter values are published in the appendix to above article:
+    Algorithm 588, DOI: 10.1145/356012.356015
+
+    The values provided here are taken from code that accompanies:
+    Key 2012, Geophysics, DOI: 10.1190/geo2011-0237.1
+
+
+    Copyright 1982 Walter L. Anderson
+
+    This work is licensed under a CC BY 4.0 license.
+    <http://creativecommons.org/licenses/by/4.0/>.
+
+
+    Returns
+    -------
+    base, j0, j1 : ndarray
+        Filter base and its values.
+
+    """
+    if 'anderson_801_1982' not in _CACHE.keys():
+        fname = 'lib/Hankel/hankel_anderson_801_1982_j0j1.txt'
+        _CACHE['anderson_801_1982'] = np.loadtxt(
+            os.path.join(_LIBPATH, fname), unpack=True)
+    return _CACHE['anderson_801_1982']
+
+
 def kong_61_2007b():
     """61 point Hankel filter, J0 and J1
 
